#[repr(C)]pub struct EngineReleaseCaptureRequest {
pub capture_image_id: ImageId,
}Fields
capture_image_id: ImageIdTrait Implementations
Sourceimpl Clone for EngineReleaseCaptureRequest
impl Clone for EngineReleaseCaptureRequest
Sourcefn clone(&self) -> EngineReleaseCaptureRequest
fn clone(&self) -> EngineReleaseCaptureRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EngineReleaseCaptureRequest
impl Debug for EngineReleaseCaptureRequest
Sourceimpl<'a, ___E> Encode<EngineReleaseCaptureRequest, ___E> for &'a EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineReleaseCaptureRequest, ___E> for &'a EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineReleaseCaptureRequest, ___E> for EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineReleaseCaptureRequest, ___E> for EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EngineReleaseCaptureRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, EngineReleaseCaptureRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EngineReleaseCaptureRequest>, ___E> for &'a EngineReleaseCaptureRequestwhere
___E: Encoder + ?Sized,
&'a EngineReleaseCaptureRequest: Encode<EngineReleaseCaptureRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EngineReleaseCaptureRequest>, ___E> for &'a EngineReleaseCaptureRequestwhere
___E: Encoder + ?Sized,
&'a EngineReleaseCaptureRequest: Encode<EngineReleaseCaptureRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineReleaseCaptureRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineReleaseCaptureRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EngineReleaseCaptureRequest>, ___E> for EngineReleaseCaptureRequestwhere
___E: Encoder + ?Sized,
EngineReleaseCaptureRequest: Encode<EngineReleaseCaptureRequest, ___E>,
impl<___E> EncodeOption<Box<'static, EngineReleaseCaptureRequest>, ___E> for EngineReleaseCaptureRequestwhere
___E: Encoder + ?Sized,
EngineReleaseCaptureRequest: Encode<EngineReleaseCaptureRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineReleaseCaptureRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineReleaseCaptureRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
impl FromWire<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineReleaseCaptureRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<EngineReleaseCaptureRequest, Self>
Sourcefn from_wire(wire: EngineReleaseCaptureRequest) -> Self
fn from_wire(wire: EngineReleaseCaptureRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
impl FromWireRef<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
Sourcefn from_wire_ref(wire: &EngineReleaseCaptureRequest) -> Self
fn from_wire_ref(wire: &EngineReleaseCaptureRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EngineReleaseCaptureRequest
impl Hash for EngineReleaseCaptureRequest
Sourceimpl Ord for EngineReleaseCaptureRequest
impl Ord for EngineReleaseCaptureRequest
Sourcefn cmp(&self, other: &EngineReleaseCaptureRequest) -> Ordering
fn cmp(&self, other: &EngineReleaseCaptureRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EngineReleaseCaptureRequest
impl PartialEq for EngineReleaseCaptureRequest
Sourcefn eq(&self, other: &EngineReleaseCaptureRequest) -> bool
fn eq(&self, other: &EngineReleaseCaptureRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EngineReleaseCaptureRequest
impl PartialOrd for EngineReleaseCaptureRequest
impl Copy for EngineReleaseCaptureRequest
impl Eq for EngineReleaseCaptureRequest
impl StructuralPartialEq for EngineReleaseCaptureRequest