#[repr(C)]pub struct EngineReleaseImageRequest {
pub image_id: ImageId,
}Fields
image_id: ImageIdTrait Implementations
Sourceimpl Clone for EngineReleaseImageRequest
impl Clone for EngineReleaseImageRequest
Sourcefn clone(&self) -> EngineReleaseImageRequest
fn clone(&self) -> EngineReleaseImageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EngineReleaseImageRequest
impl Debug for EngineReleaseImageRequest
Sourceimpl<'a, ___E> Encode<EngineReleaseImageRequest, ___E> for &'a EngineReleaseImageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineReleaseImageRequest, ___E> for &'a EngineReleaseImageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseImageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseImageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineReleaseImageRequest, ___E> for EngineReleaseImageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineReleaseImageRequest, ___E> for EngineReleaseImageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EngineReleaseImageRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, EngineReleaseImageRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseImageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseImageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EngineReleaseImageRequest>, ___E> for &'a EngineReleaseImageRequestwhere
___E: Encoder + ?Sized,
&'a EngineReleaseImageRequest: Encode<EngineReleaseImageRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EngineReleaseImageRequest>, ___E> for &'a EngineReleaseImageRequestwhere
___E: Encoder + ?Sized,
&'a EngineReleaseImageRequest: Encode<EngineReleaseImageRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineReleaseImageRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineReleaseImageRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EngineReleaseImageRequest>, ___E> for EngineReleaseImageRequest
impl<___E> EncodeOption<Box<'static, EngineReleaseImageRequest>, ___E> for EngineReleaseImageRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineReleaseImageRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineReleaseImageRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EngineReleaseImageRequest> for EngineReleaseImageRequest
impl FromWire<EngineReleaseImageRequest> for EngineReleaseImageRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineReleaseImageRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<EngineReleaseImageRequest, Self>
Sourcefn from_wire(wire: EngineReleaseImageRequest) -> Self
fn from_wire(wire: EngineReleaseImageRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<EngineReleaseImageRequest> for EngineReleaseImageRequest
impl FromWireRef<EngineReleaseImageRequest> for EngineReleaseImageRequest
Sourcefn from_wire_ref(wire: &EngineReleaseImageRequest) -> Self
fn from_wire_ref(wire: &EngineReleaseImageRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EngineReleaseImageRequest
impl Hash for EngineReleaseImageRequest
Sourceimpl Ord for EngineReleaseImageRequest
impl Ord for EngineReleaseImageRequest
Sourcefn cmp(&self, other: &EngineReleaseImageRequest) -> Ordering
fn cmp(&self, other: &EngineReleaseImageRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EngineReleaseImageRequest
impl PartialEq for EngineReleaseImageRequest
Sourcefn eq(&self, other: &EngineReleaseImageRequest) -> bool
fn eq(&self, other: &EngineReleaseImageRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EngineReleaseImageRequest
impl PartialOrd for EngineReleaseImageRequest
impl Copy for EngineReleaseImageRequest
impl Eq for EngineReleaseImageRequest
impl StructuralPartialEq for EngineReleaseImageRequest