pub struct EngineSetDisplayPowerModeRequest {
pub display_id: DisplayId,
pub power_mode: PowerMode,
}Fields
display_id: DisplayIdpower_mode: PowerModeTrait Implementations
Sourceimpl Clone for EngineSetDisplayPowerModeRequest
impl Clone for EngineSetDisplayPowerModeRequest
Sourcefn clone(&self) -> EngineSetDisplayPowerModeRequest
fn clone(&self) -> EngineSetDisplayPowerModeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for &'a EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for &'a EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EngineSetDisplayPowerModeRequest>, ___E> for &'a EngineSetDisplayPowerModeRequestwhere
___E: Encoder + ?Sized,
&'a EngineSetDisplayPowerModeRequest: Encode<EngineSetDisplayPowerModeRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EngineSetDisplayPowerModeRequest>, ___E> for &'a EngineSetDisplayPowerModeRequestwhere
___E: Encoder + ?Sized,
&'a EngineSetDisplayPowerModeRequest: Encode<EngineSetDisplayPowerModeRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineSetDisplayPowerModeRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineSetDisplayPowerModeRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EngineSetDisplayPowerModeRequest>, ___E> for EngineSetDisplayPowerModeRequestwhere
___E: Encoder + ?Sized,
EngineSetDisplayPowerModeRequest: Encode<EngineSetDisplayPowerModeRequest, ___E>,
impl<___E> EncodeOption<Box<'static, EngineSetDisplayPowerModeRequest>, ___E> for EngineSetDisplayPowerModeRequestwhere
___E: Encoder + ?Sized,
EngineSetDisplayPowerModeRequest: Encode<EngineSetDisplayPowerModeRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineSetDisplayPowerModeRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineSetDisplayPowerModeRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
impl FromWire<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
Sourcefn from_wire(wire: EngineSetDisplayPowerModeRequest) -> Self
fn from_wire(wire: EngineSetDisplayPowerModeRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
impl FromWireRef<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
Sourcefn from_wire_ref(wire: &EngineSetDisplayPowerModeRequest) -> Self
fn from_wire_ref(wire: &EngineSetDisplayPowerModeRequest) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for EngineSetDisplayPowerModeRequest
impl PartialEq for EngineSetDisplayPowerModeRequest
Sourcefn eq(&self, other: &EngineSetDisplayPowerModeRequest) -> bool
fn eq(&self, other: &EngineSetDisplayPowerModeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EngineSetDisplayPowerModeRequest