#[repr(C)]pub struct EngineStartCaptureRequest {
pub capture_image_id: ImageId,
}Fields
capture_image_id: ImageIdTrait Implementations
Sourceimpl Clone for EngineStartCaptureRequest
impl Clone for EngineStartCaptureRequest
Sourcefn clone(&self) -> EngineStartCaptureRequest
fn clone(&self) -> EngineStartCaptureRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EngineStartCaptureRequest
impl Debug for EngineStartCaptureRequest
Sourceimpl<'a, ___E> Encode<EngineStartCaptureRequest, ___E> for &'a EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineStartCaptureRequest, ___E> for &'a EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineStartCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineStartCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineStartCaptureRequest, ___E> for EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineStartCaptureRequest, ___E> for EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EngineStartCaptureRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, EngineStartCaptureRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineStartCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineStartCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EngineStartCaptureRequest>, ___E> for &'a EngineStartCaptureRequestwhere
___E: Encoder + ?Sized,
&'a EngineStartCaptureRequest: Encode<EngineStartCaptureRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EngineStartCaptureRequest>, ___E> for &'a EngineStartCaptureRequestwhere
___E: Encoder + ?Sized,
&'a EngineStartCaptureRequest: Encode<EngineStartCaptureRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineStartCaptureRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineStartCaptureRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EngineStartCaptureRequest>, ___E> for EngineStartCaptureRequest
impl<___E> EncodeOption<Box<'static, EngineStartCaptureRequest>, ___E> for EngineStartCaptureRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineStartCaptureRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineStartCaptureRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EngineStartCaptureRequest> for EngineStartCaptureRequest
impl FromWire<EngineStartCaptureRequest> for EngineStartCaptureRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineStartCaptureRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<EngineStartCaptureRequest, Self>
Sourcefn from_wire(wire: EngineStartCaptureRequest) -> Self
fn from_wire(wire: EngineStartCaptureRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<EngineStartCaptureRequest> for EngineStartCaptureRequest
impl FromWireRef<EngineStartCaptureRequest> for EngineStartCaptureRequest
Sourcefn from_wire_ref(wire: &EngineStartCaptureRequest) -> Self
fn from_wire_ref(wire: &EngineStartCaptureRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EngineStartCaptureRequest
impl Hash for EngineStartCaptureRequest
Sourceimpl Ord for EngineStartCaptureRequest
impl Ord for EngineStartCaptureRequest
Sourcefn cmp(&self, other: &EngineStartCaptureRequest) -> Ordering
fn cmp(&self, other: &EngineStartCaptureRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EngineStartCaptureRequest
impl PartialEq for EngineStartCaptureRequest
Sourcefn eq(&self, other: &EngineStartCaptureRequest) -> bool
fn eq(&self, other: &EngineStartCaptureRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EngineStartCaptureRequest
impl PartialOrd for EngineStartCaptureRequest
impl Copy for EngineStartCaptureRequest
impl Eq for EngineStartCaptureRequest
impl StructuralPartialEq for EngineStartCaptureRequest