#[repr(C)]pub struct ImageId {
pub value: u64,
}Expand description
Unique identifier for an image registered with a display engine driver.
[INVALID_ID] represents an invalid value.
Valid values uniquely identify “live” images within a display engine driver
connection. The identifier of an image destroyed via [Engine.ReleaseImage]
can be reused as the return value of a subsequent [Engine.ImportImage]
call.
Fields
value: u64Trait Implementations
Sourceimpl<'a, ___E> Encode<ImageId, ___E> for &'a ImageIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ImageId, ___E> for &'a ImageIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<ImageId, ___E> for ImageIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ImageId, ___E> for ImageIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ImageId>
const COPY_OPTIMIZATION: CopyOptimization<Self, ImageId>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ImageId>, ___E> for &'a ImageId
impl<'a, ___E> EncodeOption<Box<'static, ImageId>, ___E> for &'a ImageId
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ImageId>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ImageId>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ImageId>, ___E> for ImageId
impl<___E> EncodeOption<Box<'static, ImageId>, ___E> for ImageId
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ImageId>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ImageId>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<ImageId> for ImageId
impl FromWireRef<ImageId> for ImageId
Sourcefn from_wire_ref(wire: &ImageId) -> Self
fn from_wire_ref(wire: &ImageId) -> Self
Converts the given reference to this type.
Sourceimpl Ord for ImageId
impl Ord for ImageId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ImageId
impl PartialOrd for ImageId
impl Copy for ImageId
impl Eq for ImageId
impl StructuralPartialEq for ImageId