#[repr(C)]pub struct ConfigStamp {
pub value: Uint64,
}Expand description
The wire type corresponding to ConfigStamp.
Fields
value: Uint64Trait Implementations
Sourceimpl Clone for ConfigStamp
impl Clone for ConfigStamp
Sourcefn clone(&self) -> ConfigStamp
fn clone(&self) -> ConfigStamp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ConfigStamp
impl Constrained for ConfigStamp
Sourceimpl Debug for ConfigStamp
impl Debug for ConfigStamp
Sourceimpl<___D> Decode<___D> for ConfigStampwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ConfigStampwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ConfigStamp, ___E> for &'a ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ConfigStamp, ___E> for &'a ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ConfigStamp>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ConfigStamp>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ConfigStamp, ___E> for ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ConfigStamp, ___E> for ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ConfigStamp>
const COPY_OPTIMIZATION: CopyOptimization<Self, ConfigStamp>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ConfigStamp>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ConfigStamp>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ConfigStamp, ___E> for ConfigStamp<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<ConfigStamp, ___E> for ConfigStamp<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ConfigStamp>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ConfigStamp>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ConfigStamp> for ConfigStamp
impl FromWire<ConfigStamp> for ConfigStamp
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ConfigStamp, Self>
const COPY_OPTIMIZATION: CopyOptimization<ConfigStamp, Self>
Sourcefn from_wire(wire: ConfigStamp) -> Self
fn from_wire(wire: ConfigStamp) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ConfigStamp> for ConfigStamp
impl FromWireRef<ConfigStamp> for ConfigStamp
Sourcefn from_wire_ref(wire: &ConfigStamp) -> Self
fn from_wire_ref(wire: &ConfigStamp) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ConfigStamp
impl IntoNatural for ConfigStamp
Sourcetype Natural = ConfigStamp
type Natural = ConfigStamp
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ConfigStamp
impl Wire for ConfigStamp
Sourcetype Narrowed<'de> = ConfigStamp
type Narrowed<'de> = ConfigStamp
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.