#[repr(C)]pub struct EngineCompleteCoordinatorConnectionResponse {
pub engine_info: EngineInfo,
}Expand description
The wire type corresponding to EngineCompleteCoordinatorConnectionResponse.
Fields
engine_info: EngineInfoTrait Implementations
Sourceimpl Clone for EngineCompleteCoordinatorConnectionResponse
impl Clone for EngineCompleteCoordinatorConnectionResponse
Sourcefn clone(&self) -> EngineCompleteCoordinatorConnectionResponse
fn clone(&self) -> EngineCompleteCoordinatorConnectionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineCompleteCoordinatorConnectionResponse
impl Constrained for EngineCompleteCoordinatorConnectionResponse
Sourceimpl<___D> Decode<___D> for EngineCompleteCoordinatorConnectionResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineCompleteCoordinatorConnectionResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for &'a EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for &'a EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for EngineCompleteCoordinatorConnectionResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EngineInfo, ___E>,
impl<___E, T0> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for EngineCompleteCoordinatorConnectionResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EngineInfo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
impl FromWire<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
Sourcefn from_wire(wire: EngineCompleteCoordinatorConnectionResponse) -> Self
fn from_wire(wire: EngineCompleteCoordinatorConnectionResponse) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
impl FromWireRef<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
Sourcefn from_wire_ref(wire: &EngineCompleteCoordinatorConnectionResponse) -> Self
fn from_wire_ref(wire: &EngineCompleteCoordinatorConnectionResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineCompleteCoordinatorConnectionResponse
impl IntoNatural for EngineCompleteCoordinatorConnectionResponse
Sourcetype Natural = EngineCompleteCoordinatorConnectionResponse
type Natural = EngineCompleteCoordinatorConnectionResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineCompleteCoordinatorConnectionResponse
impl Wire for EngineCompleteCoordinatorConnectionResponse
Sourcetype Narrowed<'de> = EngineCompleteCoordinatorConnectionResponse
type Narrowed<'de> = EngineCompleteCoordinatorConnectionResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.