#[repr(C)]pub struct EngineImportImageForCaptureRequest {
pub buffer_collection_id: BufferCollectionId,
pub buffer_collection_index: Uint32,
}Expand description
The wire type corresponding to EngineImportImageForCaptureRequest.
Fields
buffer_collection_id: BufferCollectionIdbuffer_collection_index: Uint32Trait Implementations
Sourceimpl Clone for EngineImportImageForCaptureRequest
impl Clone for EngineImportImageForCaptureRequest
Sourcefn clone(&self) -> EngineImportImageForCaptureRequest
fn clone(&self) -> EngineImportImageForCaptureRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineImportImageForCaptureRequest
impl Constrained for EngineImportImageForCaptureRequest
Sourceimpl<___D> Decode<___D> for EngineImportImageForCaptureRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineImportImageForCaptureRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineImportImageForCaptureRequest, ___E> for &'a EngineImportImageForCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineImportImageForCaptureRequest, ___E> for &'a EngineImportImageForCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineImportImageForCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineImportImageForCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineImportImageForCaptureRequest, ___E> for EngineImportImageForCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineImportImageForCaptureRequest, ___E> for EngineImportImageForCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineImportImageForCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineImportImageForCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<EngineImportImageForCaptureRequest, ___E> for EngineImportImageForCaptureRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<BufferCollectionId, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<EngineImportImageForCaptureRequest, ___E> for EngineImportImageForCaptureRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<BufferCollectionId, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineImportImageForCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineImportImageForCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineImportImageForCaptureRequest> for EngineImportImageForCaptureRequest
impl FromWire<EngineImportImageForCaptureRequest> for EngineImportImageForCaptureRequest
Sourcefn from_wire(wire: EngineImportImageForCaptureRequest) -> Self
fn from_wire(wire: EngineImportImageForCaptureRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineImportImageForCaptureRequest> for EngineImportImageForCaptureRequest
impl FromWireRef<EngineImportImageForCaptureRequest> for EngineImportImageForCaptureRequest
Sourcefn from_wire_ref(wire: &EngineImportImageForCaptureRequest) -> Self
fn from_wire_ref(wire: &EngineImportImageForCaptureRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineImportImageForCaptureRequest
impl IntoNatural for EngineImportImageForCaptureRequest
Sourcetype Natural = EngineImportImageForCaptureRequest
type Natural = EngineImportImageForCaptureRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineImportImageForCaptureRequest
impl Wire for EngineImportImageForCaptureRequest
Sourcetype Narrowed<'de> = EngineImportImageForCaptureRequest
type Narrowed<'de> = EngineImportImageForCaptureRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.