#[repr(C)]pub struct EngineImportImageResponse {
pub image_id: ImageId,
}Expand description
The wire type corresponding to EngineImportImageResponse.
Fields
image_id: ImageIdTrait Implementations
Sourceimpl Clone for EngineImportImageResponse
impl Clone for EngineImportImageResponse
Sourcefn clone(&self) -> EngineImportImageResponse
fn clone(&self) -> EngineImportImageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineImportImageResponse
impl Constrained for EngineImportImageResponse
Sourceimpl Debug for EngineImportImageResponse
impl Debug for EngineImportImageResponse
Sourceimpl<___D> Decode<___D> for EngineImportImageResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineImportImageResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineImportImageResponse, ___E> for &'a EngineImportImageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineImportImageResponse, ___E> for &'a EngineImportImageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineImportImageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineImportImageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineImportImageResponse, ___E> for EngineImportImageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineImportImageResponse, ___E> for EngineImportImageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EngineImportImageResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, EngineImportImageResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineImportImageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineImportImageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EngineImportImageResponse, ___E> for EngineImportImageResponse<T0>
impl<___E, T0> Encode<EngineImportImageResponse, ___E> for EngineImportImageResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineImportImageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineImportImageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineImportImageResponse> for EngineImportImageResponse
impl FromWire<EngineImportImageResponse> for EngineImportImageResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineImportImageResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<EngineImportImageResponse, Self>
Sourcefn from_wire(wire: EngineImportImageResponse) -> Self
fn from_wire(wire: EngineImportImageResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<EngineImportImageResponse> for EngineImportImageResponse
impl FromWireRef<EngineImportImageResponse> for EngineImportImageResponse
Sourcefn from_wire_ref(wire: &EngineImportImageResponse) -> Self
fn from_wire_ref(wire: &EngineImportImageResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineImportImageResponse
impl IntoNatural for EngineImportImageResponse
Sourcetype Natural = EngineImportImageResponse
type Natural = EngineImportImageResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineImportImageResponse
impl Wire for EngineImportImageResponse
Sourcetype Narrowed<'de> = EngineImportImageResponse
type Narrowed<'de> = EngineImportImageResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.