#[repr(C)]pub struct EngineInfo {
pub max_layer_count: Uint16,
pub max_connected_display_count: Uint16,
pub is_capture_supported: bool,
}Expand description
The wire type corresponding to EngineInfo.
Fields
max_layer_count: Uint16max_connected_display_count: Uint16is_capture_supported: boolTrait Implementations
Sourceimpl Clone for EngineInfo
impl Clone for EngineInfo
Sourcefn clone(&self) -> EngineInfo
fn clone(&self) -> EngineInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineInfo
impl Constrained for EngineInfo
Sourceimpl Debug for EngineInfo
impl Debug for EngineInfo
Sourceimpl<___D> Decode<___D> for EngineInfowhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineInfowhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineInfo, ___E> for &'a EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineInfo, ___E> for &'a EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineInfo, ___E> for EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineInfo, ___E> for EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<EngineInfo, ___E> for EngineInfo<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<EngineInfo, ___E> for EngineInfo<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineInfo> for EngineInfo
impl FromWire<EngineInfo> for EngineInfo
Sourcefn from_wire(wire: EngineInfo) -> Self
fn from_wire(wire: EngineInfo) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineInfo> for EngineInfo
impl FromWireRef<EngineInfo> for EngineInfo
Sourcefn from_wire_ref(wire: &EngineInfo) -> Self
fn from_wire_ref(wire: &EngineInfo) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineInfo
impl IntoNatural for EngineInfo
Sourcetype Natural = EngineInfo
type Natural = EngineInfo
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineInfo
impl Wire for EngineInfo
Sourcetype Narrowed<'de> = EngineInfo
type Narrowed<'de> = EngineInfo
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.