#[repr(C)]pub struct EngineStartCaptureRequest {
pub capture_image_id: ImageId,
}Expand description
The wire type corresponding to EngineStartCaptureRequest.
Fields
capture_image_id: ImageIdTrait Implementations
Sourceimpl Clone for EngineStartCaptureRequest
impl Clone for EngineStartCaptureRequest
Sourcefn clone(&self) -> EngineStartCaptureRequest
fn clone(&self) -> EngineStartCaptureRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineStartCaptureRequest
impl Constrained for EngineStartCaptureRequest
Sourceimpl Debug for EngineStartCaptureRequest
impl Debug for EngineStartCaptureRequest
Sourceimpl<___D> Decode<___D> for EngineStartCaptureRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineStartCaptureRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineStartCaptureRequest, ___E> for &'a EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineStartCaptureRequest, ___E> for &'a EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineStartCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineStartCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineStartCaptureRequest, ___E> for EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineStartCaptureRequest, ___E> for EngineStartCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EngineStartCaptureRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, EngineStartCaptureRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineStartCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineStartCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EngineStartCaptureRequest, ___E> for EngineStartCaptureRequest<T0>
impl<___E, T0> Encode<EngineStartCaptureRequest, ___E> for EngineStartCaptureRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineStartCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineStartCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineStartCaptureRequest> for EngineStartCaptureRequest
impl FromWire<EngineStartCaptureRequest> for EngineStartCaptureRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineStartCaptureRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<EngineStartCaptureRequest, Self>
Sourcefn from_wire(wire: EngineStartCaptureRequest) -> Self
fn from_wire(wire: EngineStartCaptureRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<EngineStartCaptureRequest> for EngineStartCaptureRequest
impl FromWireRef<EngineStartCaptureRequest> for EngineStartCaptureRequest
Sourcefn from_wire_ref(wire: &EngineStartCaptureRequest) -> Self
fn from_wire_ref(wire: &EngineStartCaptureRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineStartCaptureRequest
impl IntoNatural for EngineStartCaptureRequest
Sourcetype Natural = EngineStartCaptureRequest
type Natural = EngineStartCaptureRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineStartCaptureRequest
impl Wire for EngineStartCaptureRequest
Sourcetype Narrowed<'de> = EngineStartCaptureRequest
type Narrowed<'de> = EngineStartCaptureRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.